#
# spec file for package cadvisor
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# nodebuginfo


%global goipath github.com/google/cadvisor
Name:           cadvisor
Version:        0.49.1
Release:        bp160.1.1
Summary:        A Simple and Comprehensive Vulnerability Scanner for Containers
License:        Apache-2.0
Group:          System/Management
URL:            https://github.com/google/cadvisor
Source:         %{name}-%{version}.tar.zst
Source1:        vendor-cmd.tar.zst
Source2:        cadvisor.service
Source3:        sysconfig.cadvisor
BuildRequires:  golang-packaging
BuildRequires:  systemd-rpm-macros
BuildRequires:  zstd
BuildRequires:  golang(API) = 1.22
Requires:       ca-certificates
Requires:       git-core
Requires:       rpm
Requires(post): %fillup_prereq

%description
cAdvisor (Container Advisor) provides container users an understanding of the
resource usage and performance characteristics of their running containers. It
is a running daemon that collects, aggregates, processes, and exports
information about running containers. Specifically, for each container it keeps
resource isolation parameters, historical resource usage, histograms of
complete historical resource usage and network statistics. This data is
exported by container and machine-wide.

cAdvisor has native support for Docker containers and should support just about
any other container type out of the box. We strive for support across the board
so feel free to open an issue if that is not the case.  cAdvisor's container
abstraction is based on lmctfy's so containers are inherently nested
hierarchically.

%prep
%setup -qa1
%autopatch -p1

%build
%{goprep} %{goipath}

pushd cmd
%{gobuild} -tags netgo -ldflags '-X github.com/google/cadvisor/version.Version=%{version}' ./cmd
popd

%install
%{goinstall}
mv %{buildroot}%{_bindir}/{cmd,cadvisor}

#
install -D -m 644 %{SOURCE2} %{buildroot}%{_unitdir}/%{name}.service
install -D -m 644 %{SOURCE3} %{buildroot}%{_fillupdir}/sysconfig.%{name}

%pre
%service_add_pre cadvisor.service

%post
%service_add_post cadvisor.service
%{fillup_only -n cadvisor}

%preun
%service_del_preun cadvisor.service

%postun
%service_del_postun cadvisor.service

%files
%license LICENSE
%doc README.md CHANGELOG.md
%{_bindir}/cadvisor
%{_unitdir}/%{name}.service
%{_fillupdir}/sysconfig.%{name}

%changelog
* Thu Jul 11 2024 dmueller@suse.com
- Update to version 0.49.1:
  * build docker - add --provenance=false flag
  * Remove s390x support
  * Disable libipmctl in build
  * Ugrade base image to 1.22 and alpine 3.18
  * fix type of C.malloc in cgo
  * Bump golang.org/x/net
  * Bump grpc
  * Update docker
  * Bump runc to v1.1.12
  * Bump to bullseye
  * Bump golang to 1.22
  * Remove section about canary image
  * Add note about WebUI auth
  * Remove mentions of accelerator from the docs
  * reduce_logs_for_kubelet_use_crio
  * upgrade actions/checkout and actions/setup-go and actions/upload-artifact
  * build(deps): bump golang.org/x/crypto from 0.14.0 to 0.17.0 in /cmd
  * add cadvisor and crio upstream changes
  * Avoid using container/podman in manager.go
  * container: skip checking for files in non-existent directories.
  * Adjust the log level of Initialize Plugins
  * add ignored device
  * fix: variable naming
  * build(deps): bump golang.org/x/net from 0.10.0 to 0.17.0 in /cmd
  * manager: require higher verbosity level for container info misses
  * Information should be logged on increased verbosity only
  * Running do mod tidy
  * Running go mod tidy
  * Running go mod tidy
  * container/libcontainer: Improve limits file parsing perf
  * container/libcontainer: Add limit parsing benchmark
  * build(deps): bump github.com/cyphar/filepath-securejoin in /cmd
  * build(deps): bump github.com/cyphar/filepath-securejoin
  * Set verbosity after flag definition
  * fix: error message typo
  * vendor: bump runc to 1.1.9
  * Switch to use busybox from registry.k8s.io
  * Bump golang ci lint to v1.54.1
  * Bump github.com/docker/docker in /cmd
  * Bump github.com/docker/docker
  * Bump github.com/docker/distribution in /cmd
  * Bump github.com/docker/distribution
  * Update genproto dependency to isolated submodule
  * remove the check for the existence of NFS files, which will cause unnecessary requests.
  * reduce inotify watch
  * fix performance degradation of NFS
  * fix: fix type issue
  * fix: fix cgo memory leak
  * ft: export memory kernel usage
  * sysinfo: Ignore "hidden" sysfs device entries
  * Increasing required verbosity level
  * Patch to fix issue 2341
  * podman support: Enable Podman support.
  * podman support: Create Podman handler.
  * podman support: Changes in Docker handler.
  * unit test: machine_swap_bytes
  * Add documentation for machine_swap_bytes metric
  * Add a machine_swap_bytes metric
  * fix: add space trimming for label allowlist
  * Upgrade to blang/semver/v4 v4.0.0
  * docs(deploy/k8s): remote build for kustomize
  * Update dependencies
  * Change filepaths to detect online CPUs
  * Update actions/checkout to v3
  * Fix flags typo
  * Updating location of kubernetes/pause image
  * Using t.TempDir() in tests
  * Unit test: MachineInfo Clone() method
  * Bugfix: MachineInfo Clone() - clone SwapCapacity
  * Optimize network metrics collection
  * Removing calls to deprecates io/ioutil package
  * Updating minimum Go version to 1.19
  * Request the pid of another container if current pid is not longer valid
  * Restructure
  * Add CRI-O client timeout setting
  * Set containerd grpc.MaxCallRecvMsgSize to 16MB
  * Fix asset build
  * feat(logging): add verbosity to non-NUMA node warning
  * add nerdctl to ignoredDevices
  * nvm: Change the "no NVM devices" log.
  * nvm: Fix typo.
  * Fix CVE-2022-27664 (#3248)
  * resctrl: Reduce size and mode files check (#3264)
  * readme: Update Creatone contributor info. (#3265)
  * Fix comment to refer to correct client
  * build: bump golang to 1.20
  * ci: Update golang ci-lint to v1.51.2
  * build: Update shebang to python3
  * Revert "dockerfile: Fix typo in go build tags."
  * Decreasing verbosity level for "Cannot read vendor id correctly, set empty"
  * dockerfile: Fix typo in go build tags.
  * deps: Move from cloud.google.com/go/compute -> cloud.google.com/go
  * use memory.min for reservation memory instead of high
  * Mark GOPATH as git safe.directory to fix CI build
  * switch to gomodule/redigo from garyburd/redigo
  * update go.mod/sum both in root and cmd/
  * Drop accelerator metrics and nvidia integration
  * Add s390x support for docker image
  * typo in MachineInfo spec for SwapCapacity
  * add support for swap in machine/info
* Thu Jun 20 2024 Dirk Müller <dmueller@suse.com>
- update description from Holden Fried (bsc#1222192)
* Thu Dec 22 2022 Dirk Müller <dmueller@suse.com>
- Initial package (0.46.0)
